Manage projects
===============

ASReview LAB offers the options to import and export projects. This can be
useful for sharing results, archiving projects, and for backup purposes.


.. figure:: ../../images/dashboard_project_options.png
   :alt: ASReview LAB Projects dashboard show options

Import Project
--------------

To import a project:

1. :doc:`start`.
2. Go to the *Projects dashboard* (http://localhost:5000/projects)
3. Click on the *Import project* icon on the top right.
4. Click on *Select file* and select a project from your device (with ``.asreview`` extension.
5. Open the project from the *Projects dashboard*.

Export Project
--------------

The ASReview project file (extension ``.asreview``) can be exported from
ASReview LAB. The file contains the dataset, review history, notes, and model
configuration. It can be imported into ASReview LAB on a different device,
which allows other users to replicate the project, or continue the systematic
review.

To export your project:

1. :doc:`start`.
2. Go to the *Projects dashboard* (http://localhost:5000/projects)
3. Hover the project you want to export and click on the *Export* icon.
4. Click on *Select file* and click on *Project*.
5. Click on *Export*

You will be asked where to save the ASReview file (extension `.asreview`).


Delete Project
--------------

To permanently delete a project, including ALL files:

1. :doc:`start`.
2. Go to the *Projects dashboard* (http://localhost:5000/projects)
3. Hover the project you want to export and click on *Options*.
4. Click on *Delete forever*.
5. This action cannot be made undone, ASReview LAB will ask you to confirm by typing in the project title.
